@@ -55,10 +55,11 @@ def lockdown_service(lockdown: LockdownClient, service_name):
 
 
 @lockdown_group.command('info', cls=Command)
+@click.option('-a', '--all', is_flag=True, help='include all domain information')
 @click.option('--color/--no-color', default=True)
-def lockdown_info(lockdown: LockdownClient, color):
+def lockdown_info(lockdown: LockdownClient, all, color):
     """ query all lockdown values """
-    print_json(lockdown.all_values, colored=color)
+    print_json(lockdown.all_domains if all else lockdown.all_values, colored=color)
 
 
 @lockdown_group.command('unpair', cls=Command)
