@@ -145,20 +145,18 @@ class MuxConnection:
 
     @staticmethod
     def create():
-        # first attempt to connect with possibly the wrong version header (binary protocol)
+        # first attempt to connect with possibly the wrong version header (plist protocol)
         sock = MuxConnection.create_usbmux_socket()
         message = usbmuxd_request.build({
-            'header': {'version': usbmuxd_version.BINARY, 'message': usbmuxd_msgtype.LISTEN, 'tag': 1},
+            'header': {'version': usbmuxd_version.PLIST, 'message': usbmuxd_msgtype.LISTEN, 'tag': 1},
             'data': b''
         })
         sock.send(message)
-
         response = usbmuxd_response.parse_stream(sock)
 
-        if response.header.message == usbmuxd_msgtype.PLIST:
-            # if we sent a bad request, we should re-create the socket in the correct version this time
-            sock.close()
-            sock = MuxConnection.create_usbmux_socket()
+        # if we sent a bad request, we should re-create the socket in the correct version this time
+        sock.close()
+        sock = MuxConnection.create_usbmux_socket()
 
         if response.header.version == usbmuxd_version.BINARY:
             return BinaryMuxConnection(sock)
@@ -248,9 +246,9 @@ class BinaryMuxConnection(MuxConnection):
         if response.header.message != usbmuxd_msgtype.RESULT:
             raise MuxException(f'unexpected message type received: {response}')
 
-        result = self._receive().result
-        if result != usbmuxd_result.OK:
-            raise MuxException(f'failed to connect to device: {device_id} at port: {port}. reason: {result}')
+        if response.data.result != usbmuxd_result.OK:
+            raise MuxException(f'failed to connect to device: {device_id} at port: {port}. reason: '
+                               f'{response.data.result}')
 
     def _send(self, data: Mapping):
         self._assert_not_connected()
@@ -265,11 +263,9 @@ class BinaryMuxConnection(MuxConnection):
         return response
 
     def _send_receive(self, message_type: int):
-        self._send(usbmuxd_request.build(
-            {'header': {'version': self._version, 'message': message_type, 'tag': self._tag},
-             'data': b''}))
+        self._send({'header': {'version': self._version, 'message': message_type, 'tag': self._tag},
+                    'data': b''})
         response = self._receive(self._tag - 1)
-
         if response.header.message != usbmuxd_msgtype.RESULT:
             raise MuxException(f'unexpected message type received: {response}')
 
